=========================================
Nose Simple and Fast Django helper plugin
=========================================

::

  $ nosetests --with-sfd

This is an update of the NoseDjango v0.6 which is incredibly fast than the
new releases. This plugin will work with all the versions of Django.

The aim of this fork is to keep the speed of the tests execution time
and provide a simple way to test Django applications with nose.

Original authors:

* Victor Ng <crankycoder@gmail.com>
* Jason Pellerin
